package com.mapmyindia.sdk.flutter.place

import android.app.Activity
import android.content.Intent
import androidx.annotation.NonNull;
import com.google.gson.Gson
import com.mapbox.mapboxsdk.MapmyIndia
import com.mapmyindia.sdk.plugins.places.autocomplete.PlaceAutocomplete
import com.mapmyindia.sdk.plugins.places.placepicker.PlacePicker
import com.mmi.services.account.MapmyIndiaAccountManager

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry
import io.flutter.plugin.common.PluginRegistry.Registrar

/** MapmyindiaPlaceFlutterPlugin */
class MapmyindiaPlaceFlutterPlugin: FlutterPlugin, MethodCallHandler, ActivityAware, PluginRegistry.ActivityResultListener {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel: MethodChannel
  private lateinit var result: Result
  private var activity: Activity? = null
  private var binding: ActivityPluginBinding? = null

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {

    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "mapmyindia_place_flutter")
    channel.setMethodCallHandler(this);
    MapmyIndia.getInstance(flutterPluginBinding.applicationContext)
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "mapmyindia_place_flutter")
      channel.setMethodCallHandler(MapmyindiaPlaceFlutterPlugin())
    }
  }

  
  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "openPlacePicker") {
      if (activity != null) {

        val pickerOption = Utils.getPickerOption(call.argument<Map<String, Any?>>("options") as Map<String, Any?>)
        val autocomplete = PlacePicker.IntentBuilder()
                .placeOptions(pickerOption)
                .build(activity!!)
        activity?.startActivityForResult(autocomplete, 101)
        binding?.addActivityResultListener(this)

        this.result = result

      } else {
        result.error("Failure", "Not attached to activity", null)
      }
    } else if (call.method == "openPlaceAutocomplete") {
      if (activity != null) {

        val placeOptions = Utils.getPlaceOptions(call.argument<Map<String, Any?>>("options") as Map<String, Any?>)
        val autocomplete = PlaceAutocomplete.IntentBuilder()
                .placeOptions(placeOptions)
                .build(activity!!)

        activity?.startActivityForResult(autocomplete, 102)
        binding?.addActivityResultListener(this)

        this.result = result
      } else {
        result.error("Failure", "Not attached to activity", null)
      }
    } else {
      result.notImplemented()
    }
  }


  override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
//    val channel = MethodChannel(binding.binaryMessenger, "flutter_place_widget_plugin")
    channel.setMethodCallHandler(null)

  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {

    this.activity = binding.activity
    this.binding = binding;
//        binding.addActivityResultListener(this)

  }

  override fun onDetachedFromActivityForConfigChanges() {
//        binding?.removeActivityResultListener(this)
    this.activity = null
    this.binding = null
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    this.activity = binding.activity
    this.binding = binding
  }

  override fun onDetachedFromActivity() {
//        binding?.removeActivityResultListener(this)

    this.activity = null
    this.binding = null
  }

  override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
    if (requestCode == 101) {
      if (resultCode == Activity.RESULT_OK) {
        result.success(Gson().toJson(PlacePicker.getPlace(data)))
        binding?.removeActivityResultListener(this)

      }
    } else if (requestCode == 102) {
      if (resultCode == Activity.RESULT_OK) {
        result.success(Gson().toJson(PlaceAutocomplete.getPlace(data)))
        binding?.removeActivityResultListener(this)
      }
    }
    return true
  }

}
