import 'package:flutter/material.dart';
import 'package:flutter_colorpicker/flutter_colorpicker.dart';
import 'package:grouped_buttons/grouped_buttons.dart';
import 'package:mapmyindia_place_flutter_example/placeSearchSettings.dart';
import 'package:mapmyindia_place_widget/mapmyindia_place_widget.dart';

class SearchSettingsWidget extends StatefulWidget {
  @override
  _SearchSettingsWidgetState createState() => _SearchSettingsWidgetState();
}

class _SearchSettingsWidgetState extends State<SearchSettingsWidget> {
  bool isTokenizeAddress = PlaceSearchSettings().tokenizeAddress;
  bool isSaveHistory = PlaceSearchSettings().saveHistory;

  // create some values
  Color backgroundColor = Color(
      int.parse(PlaceSearchSettings().backgroundColor.replaceAll("#", "0xff")));
  Color toolbarColor = Color(int.parse(PlaceSearchSettings().toolbarColor.replaceAll("#", "0xff")));

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        home: Scaffold(
            appBar: AppBar(
              title: const Text('Place Search Settings'),
            ),
            body: SingleChildScrollView(
              child: Padding(
                padding: EdgeInsets.all(10),
                child: Column(children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Tokenize Address"),
                      Switch(
                        onChanged: (bool value) {
                          PlaceSearchSettings().tokenizeAddress = value;
                          print(value);
                          setState(() {
                            isTokenizeAddress = value;
                          });
                        },
                        value: isTokenizeAddress,
                        activeColor: Colors.blue,
                        activeTrackColor: Colors.yellow,
                        inactiveThumbColor: Colors.redAccent,
                        inactiveTrackColor: Colors.orange,
                      )
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Save History"),
                      Switch(
                        onChanged: (bool value) {
                          PlaceSearchSettings().saveHistory = value;
                          print(value);
                          setState(() {
                            isSaveHistory = value;
                          });
                        },
                        value: isSaveHistory,
                        activeColor: Colors.blue,
                        activeTrackColor: Colors.yellow,
                        inactiveThumbColor: Colors.redAccent,
                        inactiveTrackColor: Colors.orange,
                      )
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("History Count"),
                      Container(
                          width: 80,
                          child: TextFormField(
                            initialValue:
                            PlaceSearchSettings().historyCount.toString(),
                            maxLength: 3,
                            onChanged: (text) {
                              PlaceSearchSettings().historyCount =
                                  int.parse(text);
                            },
                            keyboardType: TextInputType.number,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "History Count",
                            ),
                          )),
                    ],
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("attributionHorizontalAlignment"),
                      RadioButtonGroup(
                          labels: <String>["Left", "Center", "Right"],
                          picked: getLabel(PlaceSearchSettings()
                              .attributionHorizontalAlignment),
                          onSelected: (String selected) {
                            setState(() {});
                            switch (selected) {
                              case "Left":
                                PlaceSearchSettings()
                                    .attributionHorizontalAlignment =
                                    PlaceOptions.GRAVITY_LEFT;
                                break;
                              case "Center":
                                PlaceSearchSettings()
                                    .attributionHorizontalAlignment =
                                    PlaceOptions.GRAVITY_CENTER;
                                break;
                              case "Right":
                                PlaceSearchSettings()
                                    .attributionHorizontalAlignment =
                                    PlaceOptions.GRAVITY_RIGHT;
                                break;
                            }
                          })
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("attributionVerticalAlignment"),
                      RadioButtonGroup(
                          labels: <String>["Top", "Bottom"],
                          picked: getLabel(PlaceSearchSettings()
                              .attributionVerticalAlignment),
                          onSelected: (String selected) {
                            setState(() {});
                            switch (selected) {
                              case "Top":
                                PlaceSearchSettings()
                                    .attributionVerticalAlignment =
                                    PlaceOptions.GRAVITY_TOP;
                                break;
                              case "Bottom":
                                PlaceSearchSettings()
                                    .attributionVerticalAlignment =
                                    PlaceOptions.GRAVITY_BOTTOM;
                                break;
                            }
                          })
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Logo Size"),
                      RadioButtonGroup(
                          labels: <String>["Small", "Medium", "Large"],
                          picked: getLabel(PlaceSearchSettings().logoSize),
                          onSelected: (String selected) {
                            setState(() {});
                            switch (selected) {
                              case "Small":
                                PlaceSearchSettings().logoSize =
                                    PlaceOptions.SIZE_SMALL;
                                break;
                              case "Medium":
                                PlaceSearchSettings().logoSize =
                                    PlaceOptions.SIZE_MEDIUM;
                                break;
                              case "Large":
                                PlaceSearchSettings().logoSize =
                                    PlaceOptions.SIZE_LARGE;
                                break;
                            }
                          })
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Filter"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PlaceSearchSettings().filter,
                            onChanged: (text) {
                              PlaceSearchSettings().filter = text;
                            },
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Filter",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Hint"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PlaceSearchSettings().hint,
                            onChanged: (text) {
                              PlaceSearchSettings().hint = text;
                            },
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Hint",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("POD"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PlaceSearchSettings().pod,
                            onChanged: (text) {
                              PlaceSearchSettings().pod = text;
                            },
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "POD",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Background Color"),
                          Text(PlaceSearchSettings().backgroundColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: backgroundColor,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PlaceSearchSettings().backgroundColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  InkWell(
                    child: Padding(
                      padding: EdgeInsets.all(10),
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          Text("Toolbar Color"),
                          Text(PlaceSearchSettings().toolbarColor.toString())
                        ],
                      ),
                    ),
                    onTap: () {
                      showDialog(
                        context: context,
                        builder: (_) => AlertDialog(
                          title: const Text('Pick a color!'),
                          content: SingleChildScrollView(
                            child: BlockPicker(
                              pickerColor: toolbarColor,
                              onColorChanged: (color) {
                                setState(() {
                                  var hex = '#${color.value.toRadixString(16)}';
                                  PlaceSearchSettings().toolbarColor = hex;
                                  //print(hex);
                                });
                              },
                            ),
                          ),
                          actions: <Widget>[
                            FlatButton(
                              child: const Text('Got it'),
                              onPressed: () {
                                Navigator.of(context).pop();
                              },
                            ),
                          ],
                        ),
                      );
                    },
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Zoom"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PlaceSearchSettings().zoom.toString(),
                            onChanged: (text) {
                              PlaceSearchSettings().zoom = double.parse(text);
                            },
                            keyboardType:TextInputType.number ,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "zoom",
                            ),
                          )),
                    ],
                  ),
                  Divider(
                    color: Colors.grey,
                    height: 5,
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Text("Location"),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PlaceSearchSettings().locationLat.toString(),
                            onChanged: (text) {
                              PlaceSearchSettings().locationLat = double.parse(text);
                            },
                            keyboardType:TextInputType.number ,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Lat",
                            ),
                          )),
                      Container(
                          width: 150,
                          child: TextFormField(
                            initialValue: PlaceSearchSettings().locationLng.toString(),
                            onChanged: (text) {
                              PlaceSearchSettings().locationLng = double.parse(text);
                            },
                            keyboardType:TextInputType.number ,
                            decoration: InputDecoration(
                              border: OutlineInputBorder(),
                              hintText: "Lng",
                            ),
                          )),
                    ],
                  ),
                ]),
              ),
            )));
  }

  String? getLabel(int data) {
    switch (data) {
      case 1:
        return "Left";
      case 2:
        return "Center";
      case 3:
        return "Right";
      case 4:
        return "Top";
      case 5:
        return "Bottom";
      case 6:
        return "Small";
      case 7:
        return "Medium";
      case 8:
        return "Large";
    }
    return null;
  }
}
