part of mapmyindia_place_widget;

class PickerOption {
  final bool? includeDeviceLocationButton;
  final bool? includeSearch;
  final double? mapMaxZoom;
  final double? mapMinZoom;
  final PlaceOptions? placeOptions;
  final String? toolbarColor;
  final Uint8List? marker;
  final CameraPosition? statingCameraPosition;
  final LatLngBounds? startingBounds;
  final String? toolbarTintColor;
  final String? placeNameLabelTextColor;
  final String? pickerButtonTitleColor;
  final String? pickerButtonTitle;
  final String? pickerButtonBackgroundColor;
  final String? addressTextColor;
  final bool? showMarkerShadow;


  // ios proprities
  final Uint8List? searchButtonImage;
  final String? infoBottomViewBackgroundColor;

  PickerOption({this.includeDeviceLocationButton,
    this.includeSearch,
    this.mapMaxZoom,
    this.mapMinZoom,
    this.placeOptions,
    this.toolbarColor,
    this.marker,
    this.statingCameraPosition,
    this.startingBounds,
    this.toolbarTintColor,
    this.placeNameLabelTextColor,
    this.pickerButtonTitleColor,
    this.pickerButtonTitle,
    this.pickerButtonBackgroundColor,
    this.addressTextColor,
    this.showMarkerShadow,


    // ios
    this.searchButtonImage,
    this.infoBottomViewBackgroundColor
  });

  Map<String, dynamic> toMap() {
    final Map<String, dynamic> optionsMap = <String, dynamic>{};

    void addIfNonNull(String fieldName, dynamic value) {
      if (value != null) {
        optionsMap[fieldName] = value;
      }
    }
    void addMapIfNonNull(String fieldName, Uint8List value) {
      if (value != null) {
        optionsMap[fieldName] = <String, dynamic>{
          'image': value,
          'length': value.length
        };
      }
    }

    addIfNonNull('includeDeviceLocationButton', includeDeviceLocationButton);//Android Only
    addIfNonNull('includeSearch', includeSearch);
    addIfNonNull('mapMaxZoom', mapMaxZoom);
    addIfNonNull('mapMinZoom', mapMinZoom);
    addIfNonNull('searchPlaceOption', placeOptions?.toMap());
    addIfNonNull('toolbarColor', toolbarColor);
    addIfNonNull('statingCameraPosition', statingCameraPosition?.toMap());
    addIfNonNull('startingBounds', startingBounds?.toList());
    if (marker != null) {
      addMapIfNonNull('marker', marker!);
    }
    addIfNonNull('toolbarTintColor', toolbarTintColor);//Android Only
    addIfNonNull("placeNameLabelTextColor", placeNameLabelTextColor);
    addIfNonNull("pickerButtonTitleColor", pickerButtonTitleColor);
    addIfNonNull("pickerButtonTitle", pickerButtonTitle);
    addIfNonNull("pickerButtonBackgroundColor", pickerButtonBackgroundColor);

    //new
    addIfNonNull('addressTextColor', addressTextColor);
    addIfNonNull('showMarkerShadow', showMarkerShadow);

    // ios
    addIfNonNull("infoBottomViewBackgroundColor", infoBottomViewBackgroundColor);
    if(searchButtonImage != null) {
      addMapIfNonNull('searchButtonImage', searchButtonImage!);
    }

    return optionsMap;
  }

}
